# frozen_string_literal: true
Rails.configuration.to_prepare do
  middleware_stack = Middleware::Builder.new do |b|
  end

  command_bus = NexusCqrs::CommandBus.new(middleware: middleware_stack)
  query_bus = NexusCqrs::CommandBus.new(middleware: middleware_stack)

  $COMMAND_EXECUTOR = NexusCqrs::CommandExecutor.new(command_bus)
  $QUERY_EXECUTOR = NexusCqrs::CommandExecutor.new(query_bus)

  # Register Commands
  $QUERY_EXECUTOR.configure_handlers do |executor|
    # Manually registered queries should always go above the autoregister

    executor.autoregister(NexusCqrs::BaseQuery, 'app/domain/queries')
  end

  $COMMAND_EXECUTOR.configure_handlers do |executor|
    # Manually registered commands should always go above the autoregister

    executor.autoregister(NexusCqrs::BaseCommand, 'app/domain/commands')
  end
end
