# frozen_string_literal: true
module NexusCqrs
  # Simple module to inject execution methods into a class. Used to execute commands and queries from controllers and/or
  # graphql resolvers.
  module Helpers
    # Executes a CQRS Command
    #
    # @param [NexusCqrs::BaseCommand] command Command to execute
    # @example Execute a command
    #     execute(DeleteMod.new(mod.id))
    def execute(command)
      command_executor.execute(command)
    end

    # Executes a CQRS Query
    #
    # @param [NexusCqrs::BaseQuery] query Query to execute
    # @example Execute a query
    #     execute(GetMod.new(mod.id))
    def query(query)
      query_executor.execute(query)
    end

    # Provide access to the CQRS command executor
    #
    # @return [NexusCqrs::CommandExecutor] Returns the executor used for commands
    def command_executor
      @command_executor ||= $COMMAND_EXECUTOR
    end

    # Provide access to the CQRS query executor
    #
    # @return [NexusCqrs::CommandExecutor] Returns the executor used for queries
    def query_executor
      @query_executor ||= $QUERY_EXECUTOR
    end
  end
end
